/*
 *    PhindService.java
 *    Copyright (C) 2002 New Zealand Digital Library, http://www.nzdl.org
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package org.greenstone.gsdl3.service;

import org.w3c.dom.Document; 
import org.w3c.dom.Node; 
import org.w3c.dom.Element; 
import org.w3c.dom.Text; 

/** 
 * PhindService - the phind phrase browsing service
 * 
 * @author <a href="mailto:kjdon@cs.waikato.ac.nz">Katherine Don</a>
 * @version $Revision: 3377 $
 */
public class PhindService 
    extends ServiceModule {

    
    protected Element processService(String name, Element request) {

	if (!name.equals("PhindApplet")) {
	    System.err.println("PhindService:you have asked for a non-existant service - "+name+"!");
	    return null;
	}
	// create dummy response
	Element res = doc_.createElement("response");
	res.setAttribute("from", "PhindApplet");
	Element data = doc_.createElement("content");
	Text t = doc_.createTextNode("this is the results for a phind request");
	data.appendChild(t);
	
	res.appendChild(data);

	return res;
	
    }
    /** configure the service module
     *
     * @param info a DOM Element containing any config info for the service
     * @return true if configured
     */
    public boolean configure(Element info) {

	System.out.println("configuring PhindService");

	// set up short_service_info_ - for now just has name and type
	Element e = doc_.createElement("service");
	e.setAttribute("type", "query");
	e.setAttribute("name", "PhindApplet");
	short_service_info_.appendChild(e);

	// set up service_info_map_ - we only have one element, and it has
	// no extra info yet - we are not processing the config info
	Element f = doc_.createElement("service");
	f.setAttribute("type", "query");
	f.setAttribute("name", "PhindApplet");

	// add in teh applet info for the phind applet
	String app_info = "<applet CODEBASE='/gsdl3/lib/java' CODE='org.greenstone.applet.phind.Phind.class' ARCHIVE='phind.jar' WIDTH='500' HEIGHT='400'><PARAM NAME='library'     VALUE='/gsdl3/library'/> <PARAM NAME='phindcgi' VALUE='/gsdl3/library?a=b&amp;sa=phind'/> <PARAM NAME='collection'   VALUE='mgppdemo'/> <PARAM NAME='classifier'   VALUE='1'/>  <PARAM NAME='orientation'  VALUE='vertical'/> <PARAM NAME='depth'        VALUE='2'/> <PARAM NAME='resultorder' VALUE='L,l,E,e,D,d'/> <PARAM NAME='backdrop'     VALUE='/gsdl3/interfaces/default/images/phindbg1.jpg'/><PARAM NAME='fontsize'     VALUE='10'/> <PARAM NAME='blocksize'    VALUE='10'/>The Phind java applet.</applet>";

	Document dom = converter_.getDOM(app_info);
	Element app_elem = dom.getDocumentElement();
	f.appendChild(doc_.importNode(app_elem, true));
	
	service_info_map_.put("PhindApplet", f);
	
	return true;
    }

    
}
